%global longname include-what-you-use
%global owner %{longname}
%global commit0 98f3e62d371ae602061951115efc3b75ff255824

Name:           iwyu
Version:        0.5
Release:        1%{?dist}
Summary:        C/C++ source files #include analyzer based on clang

License:        NCSA
URL:            https://github.com/%{owner}/%{longname}
Source0:        https://github.com/%{owner}/%{longname}/archive/%{commit0}.tar.gz#/%{longname}-%{commit0}.tar.gz

BuildRequires:  cmake
BuildRequires:  clang-devel >= 3.7
# NOTE: This should probably listed as a dependency for clang-devel but it's
# not, so make it explicit here
BuildRequires:  llvm-devel
# Some of the Clang libraries are only available statically and the use of the
# static library was approved (see https://fedorahosted.org/fesco/ticket/1370 )
BuildRequires:  llvm-static
BuildRequires:  zlib-devel
# Scripts are Python 2
BuildRequires:  python2-devel

# Virtual provide the long name
Provides:  include-what-you-use = %{version}-%{release}
Provides:  include-what-you-use%{?_isa} = %{version}-%{release}

# It isn't building on ARM, so just exclude it for now (see https://bugzilla.redhat.com/show_bug.cgi?id=1192713 )
# Also, the tests use x86 assembly right now (see https://groups.google.com/forum/#!topic/include-what-you-use/lEuN5tr-0y0 )
ExclusiveArch: %{ix86} x86_64


%description
"Include what you use" means this: for every symbol (type, function, variable,
or macro) that you use in foo.cc (or foo.cpp), either foo.cc or foo.h
should #include a .h file that exports the declaration of that symbol. The
include-what-you-use tool is a program that can be built with the clang
libraries in order to analyze #includes of source files to find
include-what-you-use violations, and suggest fixes for them. 


%prep
%setup -q -n %{longname}-%{commit0}


%build
mkdir build
cd build
# NOTE: Have to specify both lib and include dir for it to work
%cmake -DIWYU_LLVM_LIB_PATH=%{_libdir}/llvm -DIWYU_LLVM_INCLUDE_PATH=%{_includedir} ..
make %{?_smp_mflags}


%install
%make_install DESTDIR=%{buildroot} -C build
cd %{buildroot}%{_bindir}
ln -s include-what-you-use iwyu
ln -s fix_includes.py fix_includes
ln -s iwyu_tool.py iwyu_tool


%check
# Need to have the clang header's at the correct relative path (see https://github.com/include-what-you-use/include-what-you-use/issues/100 )
%global clang_version  %(ls -t /usr/lib/clang/ | head -n 1 || echo "666")
mkdir -p lib/clang/%{clang_version}/
ln -s /usr/lib/clang/%{clang_version}/include lib/clang/%{clang_version}
cd build
PATH=$PWD:$PATH
ln -s ../fix_includes.py
ln -s ../fix_includes_test.py
ln -s ../iwyu_test_util.py
ln -s ../run_iwyu_tests.py
ln -s ../tests
%{__python2} run_iwyu_tests.py
%{__python2} fix_includes_test.py


%files
%{_bindir}/include-what-you-use
%{_bindir}/iwyu
%{_bindir}/fix_includes
%{_bindir}/fix_includes.py
%{_bindir}/iwyu_tool
%{_bindir}/iwyu_tool.py


%changelog
* Wed Sep 30 2015 Dave Johansen <davejohansen@gmail.com> - 0.5-1
- Upstream release

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 04 2015 Dave Johansen <davejohansen@gmail.com> - 0.4-2
- Added iwyu_tool

* Mon Jun 01 2015 Dave Johansen <davejohansen@gmail.com> - 0.4-1
- Update to 0.4 based on clang 3.6.0

* Tue Jan 27 2015 Dave Johansen <davejohansen@gmail.com> - 0.3-1
- Update to 0.3 based on clang 3.5.0

* Fri Apr 25 2014 Dave Johansen <davejohansen@gmail.com> - 0.2-1
- Initial RPM release
